Learn R Programming

eventstudies (version 1.0)

remap.cumsum: This function gives the cumulative total of the values ( in level or percentage form ).

Description

This function gives the cumulative total of the values.

Usage

remap.cumsum(z, is.pc = TRUE, base = 0)

Arguments

Value

The frame returned has each column replaced by the cumulative sum of the column.

See Also

eventDays, eventstudyData, phys2eventtime

Examples

Run this code
data(StockPriceReturns)
data(SplitDates)
es.results <- phys2eventtime(z=StockPriceReturns, events=SplitDates,width=5)
es.w <- window(es.results$z.e, start=-5, end=+5)
eventtime <- remap.cumsum(es.w, is.pc=FALSE, base=0)

Run the code above in your browser using DataLab